@@ -94,15 +94,16 @@ class GeometricParameters(BaseParameters):
             "Positive area-weighted particle-size standard deviation [m]"
         )
 
-    def R_n_dimensional(self, x):
-        """Negative particle radius as a function of through-cell distance"""
-        inputs = {"Through-cell distance (x_n) [m]": x}
-        return pybamm.FunctionParameter("Negative particle radius [m]", inputs)
-
-    def R_p_dimensional(self, x):
-        """Positive particle radius as a function of through-cell distance"""
-        inputs = {"Through-cell distance (x_p) [m]": x}
-        return pybamm.FunctionParameter("Positive particle radius [m]", inputs)
+        x_n = pybamm.standard_spatial_vars.x_n
+        x_p = pybamm.standard_spatial_vars.x_p
+        self.R_n_dimensional = pybamm.FunctionParameter(
+            "Negative particle radius [m]",
+            {"Through-cell distance (x_n) [m]": x_n * self.L_x},
+        )
+        self.R_p_dimensional = pybamm.FunctionParameter(
+            "Positive particle radius [m]",
+            {"Through-cell distance (x_p) [m]": x_p * self.L_x},
+        )
 
     def f_a_dist_n_dimensional(self, R):
         """
@@ -134,9 +135,8 @@ class GeometricParameters(BaseParameters):
         # Microscale geometry
         # Note: these scales are necessary here to non-dimensionalise the
         # particle size distributions.
-        # Use typical values at electrode/current collector interface.
-        self.R_n_typ = self.R_n_dimensional(0)
-        self.R_p_typ = self.R_p_dimensional(self.L_x)
+        self.R_n_typ = pybamm.xyz_average(self.R_n_dimensional)
+        self.R_p_typ = pybamm.xyz_average(self.R_p_dimensional)
 
     def _set_dimensionless_parameters(self):
         """Defines the dimensionless parameters."""
@@ -176,21 +176,9 @@ class GeometricParameters(BaseParameters):
         self.sd_a_n = self.sd_a_n_dim / self.R_n_typ
         self.sd_a_p = self.sd_a_p_dim / self.R_p_typ
 
-    def R_n(self, x):
-        """
-        Dimensionless negative particle radius as a function of dimensionless
-        position x
-        """
-        x_dim = x * self.L_x
-        return self.R_n_dimensional(x_dim) / self.R_n_typ
-
-    def R_p(self, x):
-        """
-        Dimensionless positive particle radius as a function of dimensionless
-        position x
-        """
-        x_dim = x * self.L_x
-        return self.R_p_dimensional(x_dim) / self.R_p_typ
+        # Particle radius
+        self.R_n = self.R_n_dimensional / self.R_n_typ
+        self.R_p = self.R_p_dimensional / self.R_p_typ
 
     def f_a_dist_n(self, R):
         """
